@@ -14,9 +14,9 @@
 # above as well as the notices contained in other source files with your
 # own copyright notice.  Recommended free  licenses are  the GNU General
 # Public License, GNU Lesser General Public License, Expat License, or
-# Apache License 2.0.
+# Apache License.
 
-__all__ = ['Room']
+import sge
 
 
 class Room(object):
@@ -128,6 +128,29 @@ class Room(object):
         """
         # TODO
 
+    def set_alarm(self, alarm_id, value):
+        """Set an alarm.
+
+        After this method is called, ``value`` will reduce by 1 each
+        frame (adjusted for delta timing if it is enabled) until it
+        reaches 0, at which point :meth:`sge.Room.event_alarm` will be
+        executed with ``alarm_id``.
+
+        See the documentation for :meth:`sge.Game.set_alarm` for more
+        information.
+
+        """
+        # TODO
+
+    def get_alarm(self, alarm_id):
+        """Return the value of an alarm.
+
+        See the documentation for :meth:`sge.Game.get_alarm` for more
+        information.
+
+        """
+        # TODO
+
     def end(self, next_room=None, resume=True):
         """End the current room.
 
@@ -321,10 +344,8 @@ class Room(object):
         Called when the room resumes without being reset to its original
         state (i.e. via :meth:`sge.Room.resume`).
 
-        By default, this calls :meth:`sge.Room.event_room_start`.
-
         """
-        self.event_room_start()
+        pass
 
     def event_room_end(self):
         """Room end event.
@@ -344,11 +365,20 @@ class Room(object):
         """
         pass
 
+    def event_alarm(self, alarm_id):
+        """Alarm event.
+
+        See the documentation for :meth:`sge.Game.event_alarm` for more
+        information.
+
+        """
+        pass
+
     def event_key_press(self, key, char):
         """Key press event.
 
-        See the documentation for :meth:`sge.Game.event_key_press` for
-        more information.
+        See the documentation for :class:`sge.input.KeyPress` for more
+        information.
 
         """
         pass
@@ -356,8 +386,8 @@ class Room(object):
     def event_key_release(self, key):
         """Key release event.
 
-        See the documentation for :meth:`sge.Game.event_key_release` for
-        more information.
+        See the documentation for :class:`sge.input.KeyRelease` for more
+        information.
 
         """
         pass
@@ -365,8 +395,8 @@ class Room(object):
     def event_mouse_move(self, x, y):
         """Mouse move event.
 
-        See the documentation for :meth:`sge.Game.event_mouse_move` for
-        more information.
+        See the documentation for :class:`sge.input.MouseMove` for more
+        information.
 
         """
         pass
@@ -374,8 +404,8 @@ class Room(object):
     def event_mouse_button_press(self, button):
         """Mouse button press event.
 
-        See the documentation for
-        :meth:`sge.Game.event_mouse_button_press` for more information.
+        See the documentation for :class:`sge.input.MouseButtonPress`
+        for more information.
 
         """
         pass
@@ -383,57 +413,53 @@ class Room(object):
     def event_mouse_button_release(self, button):
         """Mouse button release event.
 
-        See the documentation for
-        :meth:`sge.Game.event_mouse_button_release` for more
-        information.
+        See the documentation for :class:`sge.input.MouseButtonRelease`
+        for more information.
 
         """
         pass
 
-    def event_joystick_axis_move(self, name, ID, axis, value):
+    def event_joystick_axis_move(self, js_name, js_id, axis, value):
         """Joystick axis move event.
 
-        See the documentation for
-        :meth:`sge.Game.event_joystick_axis_move` for more information.
+        See the documentation for :class:`sge.input.JoystickAxisMove`
+        for more information.
 
         """
         pass
 
-    def event_joystick_hat_move(self, name, ID, hat, x, y):
-        """Joystick HAT move event.
+    def event_joystick_hat_move(self, js_name, js_id, hat, x, y):
+        """Joystick hat move event.
 
-        See the documentation for
-        :meth:`sge.Game.event_joystick_hat_move` for more information.
+        See the documentation for :class:`sge.input.JoystickHatMove` for
+        more information.
 
         """
         pass
 
-    def event_joystick_trackball_move(self, name, ID, ball, x, y):
+    def event_joystick_trackball_move(self, js_name, js_id, ball, x, y):
         """Joystick trackball move event.
 
         See the documentation for
-        :meth:`sge.Game.event_joystick_trackball_move` for more
-        information.
+        :class:`sge.input.JoystickTrackballMove` for more information.
 
         """
         pass
 
-    def event_joystick_button_press(self, name, ID, button):
+    def event_joystick_button_press(self, js_name, js_id, button):
         """Joystick button press event.
 
-        See the documentation for
-        :meth:`sge.Game.event_joystick_button_press` for more
-        information.
+        See the documentation for :class:`sge.input.JoystickButtonPress`
+        for more information.
 
         """
         pass
 
-    def event_joystick_button_release(self, name, ID, button):
+    def event_joystick_button_release(self, js_name, js_id, button):
         """Joystick button release event.
 
         See the documentation for
-        :meth:`sge.Game.event_joystick_button_release` for more
-        information.
+        :class:`sge.input.JoystickButtonRelease` for more information.
 
         """
         pass
@@ -441,8 +467,8 @@ class Room(object):
     def event_gain_keyboard_focus(self):
         """Gain keyboard focus event.
 
-        See the documentation for
-        :meth:`sge.Game.event_gain_keyboard_focus` for more information.
+        See the documentation for :class:`sge.input.KeyboardFocusGain`
+        for more information.
 
         """
         pass
@@ -450,8 +476,8 @@ class Room(object):
     def event_lose_keyboard_focus(self):
         """Lose keyboard focus event.
 
-        See the documentation for
-        :meth:`sge.Game.event_lose_keyboard_focus` for more information.
+        See the documentation for :class:`sge.input.KeyboardFocusLose`
+        for more information.
 
         """
         pass
@@ -459,8 +485,8 @@ class Room(object):
     def event_gain_mouse_focus(self):
         """Gain mouse focus event.
 
-        See the documentation for
-        :meth:`sge.Game.event_gain_mouse_focus` for more information.
+        See the documentation for :class:`sge.input.MouseFocusGain` for
+        more information.
 
         """
         pass
@@ -468,8 +494,8 @@ class Room(object):
     def event_lose_mouse_focus(self):
         """Lose mouse focus event.
 
-        See the documentation for
-        :meth:`sge.Game.event_lose_mouse_focus` for more information.
+        See the documentation for :class:`sge.input.MouseFocusLose` for
+        more information.
 
         """
         pass
@@ -477,18 +503,20 @@ class Room(object):
     def event_close(self):
         """Close event.
 
-        See the documentation for :meth:`sge.Game.event_close` for more
-        information.  This is always called before any game close events
+        This is always called before any :meth:`sge.Game.event_close`
         occurring at the same time.
 
+        See the documentation for :class:`sge.input.QuitRequest` for
+        more information.
+
         """
         pass
 
     def event_paused_key_press(self, key, char):
         """Key press event when paused.
 
-        See the documentation for :meth:`sge.Game.event_key_press` for
-        more information.
+        See the documentation for :class:`sge.input.KeyPress` for more
+        information.
 
         """
         pass
@@ -496,8 +524,8 @@ class Room(object):
     def event_paused_key_release(self, key):
         """Key release event when paused.
 
-        See the documentation for :meth:`sge.Game.event_key_release` for
-        more information.
+        See the documentation for :class:`sge.input.KeyRelease` for more
+        information.
 
         """
         pass
@@ -505,8 +533,8 @@ class Room(object):
     def event_paused_mouse_move(self, x, y):
         """Mouse move event when paused.
 
-        See the documentation for :meth:`sge.Game.event_mouse_move` for
-        more information.
+        See the documentation for :class:`sge.input.MouseMove` for more
+        information.
 
         """
         pass
@@ -514,8 +542,8 @@ class Room(object):
     def event_paused_mouse_button_press(self, button):
         """Mouse button press event when paused.
 
-        See the documentation for
-        :meth:`sge.Game.event_mouse_button_press` for more information.
+        See the documentation for :class:`sge.input.MouseButtonPress`
+        for more information.
 
         """
         pass
@@ -523,57 +551,53 @@ class Room(object):
     def event_paused_mouse_button_release(self, button):
         """Mouse button release event when paused.
 
-        See the documentation for
-        :meth:`sge.Game.event_mouse_button_release` for more
-        information.
+        See the documentation for :class:`sge.input.MouseButtonRelease`
+        for more information.
 
         """
         pass
 
-    def event_paused_joystick_axis_move(self, name, ID, axis, value):
+    def event_paused_joystick_axis_move(self, js_name, js_id, axis, value):
         """Joystick axis move event when paused.
 
-        See the documentation for
-        :meth:`sge.Game.event_joystick_axis_move` for more information.
+        See the documentation for :class:`sge.input.JoystickAxisMove`
+        for more information.
 
         """
         pass
 
-    def event_paused_joystick_hat_move(self, name, ID, hat, x, y):
-        """Joystick HAT move event when paused.
+    def event_paused_joystick_hat_move(self, js_name, js_id, hat, x, y):
+        """Joystick hat move event when paused.
 
-        See the documentation for
-        :meth:`sge.Game.event_joystick_hat_move` for more information.
+        See the documentation for :class:`sge.input.JoystickHatMove` for
+        more information.
 
         """
         pass
 
-    def event_paused_joystick_trackball_move(self, name, ID, ball, x, y):
+    def event_paused_joystick_trackball_move(self, js_name, js_id, ball, x, y):
         """Joystick trackball move event when paused.
 
         See the documentation for
-        :meth:`sge.Game.event_joystick_trackball_move` for more
-        information.
+        :class:`sge.input.JoystickTrackballMove` for more information.
 
         """
         pass
 
-    def event_paused_joystick_button_press(self, name, ID, button):
+    def event_paused_joystick_button_press(self, js_name, js_id, button):
         """Joystick button press event when paused.
 
-        See the documentation for
-        :meth:`sge.Game.event_joystick_button_press` for more
-        information.
+        See the documentation for :class:`sge.input.JoystickButtonPress`
+        for more information.
 
         """
         pass
 
-    def event_paused_joystick_button_release(self, name, ID, button):
+    def event_paused_joystick_button_release(self, js_name, js_id, button):
         """Joystick button release event when paused.
 
         See the documentation for
-        :meth:`sge.Game.event_joystick_button_release` for more
-        information.
+        :class:`sge.input.JoystickButtonRelease` for more information.
 
         """
         pass
@@ -581,8 +605,8 @@ class Room(object):
     def event_paused_gain_keyboard_focus(self):
         """Gain keyboard focus event when paused.
 
-        See the documentation for
-        :meth:`sge.Game.event_gain_keyboard_focus` for more information.
+        See the documentation for :class:`sge.input.KeyboardFocusGain`
+        for more information.
 
         """
         pass
@@ -590,8 +614,8 @@ class Room(object):
     def event_paused_lose_keyboard_focus(self):
         """Lose keyboard focus event when paused.
 
-        See the documentation for
-        :meth:`sge.Game.event_lose_keyboard_focus` for more information.
+        See the documentation for :class:`sge.input.KeyboardFocusLose`
+        for more information.
 
         """
         pass
@@ -599,8 +623,8 @@ class Room(object):
     def event_paused_gain_mouse_focus(self):
         """Gain mouse focus event when paused.
 
-        See the documentation for
-        :meth:`sge.Game.event_gain_mouse_focus` for more information.
+        See the documentation for :class:`sge.input.MouseFocusGain` for
+        more information.
 
         """
         pass
@@ -608,8 +632,8 @@ class Room(object):
     def event_paused_lose_mouse_focus(self):
         """Lose mouse focus event when paused.
 
-        See the documentation for
-        :meth:`sge.Game.event_lose_mouse_focus` for more information.
+        See the documentation for :class:`sge.input.MouseFocusLose` for
+        more information.
 
         """
         pass
@@ -617,7 +641,7 @@ class Room(object):
     def event_paused_close(self):
         """Close event when paused.
 
-        See the documentation for :meth:`sge.Game.event_close` for more
+        See the documentation for :meth:`sge.Room.event_close` for more
         information.
 
         """
